==> media_entity_slideshare-8.x-1.0.tar.gz: media_entity_slideshare/src/Plugin/Field/FieldFormatter/SlideShareEmbedFormatter.php <==
<?php

namespace Drupal\media_entity_slideshare\Plugin\Field\FieldFormatter;

use Drupal\Core\Field\FieldItemListInterface;
use Drupal\Core\Field\FormatterBase;
use Drupal\Core\Form\FormStateInterface;
use Drupal\media_entity\EmbedCodeValueTrait;
use Drupal\media_entity_slideshare\Plugin\MediaEntity\Type\SlideShare;
use Drupal\Core\Plugin\ContainerFactoryPluginInterface;
use Drupal\Core\Field\FieldDefinitionInterface;
use Drupal\Core\Config\ConfigFactory;
use Symfony\Component\DependencyInjection\ContainerInterface;
use ZendService\SlideShare\SlideShare as ZendSlideShare;
use ZendService\SlideShare\Exception\RuntimeException;
use ZendService\SlideShare\HttpException\RuntimeException as HttpRuntimeException;
use GuzzleHttp\Client;

/**
 * Plugin implementation of the 'slideshare_embed' formatter.
 *
 * @FieldFormatter(
 *   id = "slideshare_embed",
 *   label = @Translation("SlideShare embed"),
 *   field_types = {
 *     "link", "string", "string_long"
 *   }
 * )
 */
class SlideShareEmbedFormatter extends FormatterBase implements ContainerFactoryPluginInterface {

  use EmbedCodeValueTrait;

  const URL = '//www.slideshare.net/slideshow/embed_code/key/';

  const API_URL = 'https://www.slideshare.net/api/2/get_slideshow';

  /**
   * HTTP client.
   *
   * @var \GuzzleHttp\Client $httpClient
   */
  protected $httpClient;

  /**
   * API key.
   *
   * @var string $apiKey
   */
  protected $apiKey;

  /**
   * Shared secret.
   *
   * @var string $sharedSecret
   */
  protected $sharedSecret;

  /**
   * Constructs a new SlideShareEmbedFormatter.
   *
   * @param string $plugin_id
   *   The plugin_id for the formatter.
   * @param mixed $plugin_definition
   *   The plugin implementation definition.
   * @param \Drupal\Core\Field\FieldDefinitionInterface $field_definition
   *   The definition of the field to which the formatter is associated.
   * @param array $settings
   *   The formatter settings.
   * @param string $label
   *   The formatter label display setting.
   * @param string $view_mode
   *   The view mode.
   * @param array $third_party_settings
   *   Third party settings.
   * @param \GuzzleHttp\Client $http_client
   *   The date formatter service.
   * @param \Drupal\Core\Config\ConfigFactory $config
   *   Configuration.
   */
  public function __construct($plugin_id, $plugin_definition, FieldDefinitionInterface $field_definition, array $settings, $label, $view_mode, array $third_party_settings, Client $http_client, ConfigFactory $config) {
    parent::__construct($plugin_id, $plugin_definition, $field_definition, $settings, $label, $view_mode, $third_party_settings);

    $this->httpClient = $http_client;
    $this->apiKey = $config->get('media_entity_slideshare.settings')->get('api_key');
    $this->sharedSecret = $config->get('media_entity_slideshare.settings')->get('shared_secret');
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container, array $configuration, $plugin_id, $plugin_definition) {
    return new static(
      $plugin_id,
      $plugin_definition,
      $configuration['field_definition'],
      $configuration['settings'],
      $configuration['label'],
      $configuration['view_mode'],
      $configuration['third_party_settings'],
      $container->get('http_client'),
      $container->get('config.factory')
    );
  }

  /**
   * {@inheritdoc}
   */
  public function viewElements(FieldItemListInterface $items, $langcode) {
    $element = [];
    $settings = $this->getSettings();

    foreach ($items as $delta => $item) {
      $slideshow_url = NULL;
      $matches = [];
      foreach (SlideShare::$validationRegexp as $pattern => $key) {
        if (preg_match($pattern, $this->getEmbedCode($item), $matches)) {
          break;
        }
      }

      if (!empty($matches['secretkey'])) {
        $slideshow_url = static::URL . $matches['secretkey'];
      }
      elseif (!empty($matches['shortcode'])) {
        $slideshow_url = $this->getSlideshowUrl($matches['login'], $matches['shortcode']);
      }

      if ($slideshow_url) {
        $element[$delta] = [
          '#type' => 'html_tag',
          '#tag' => 'iframe',
          '#attributes' => [
            'allowfullscreen' => 'true',
            'frameborder' => 0,
            'scrolling' => 'no',
            'src' => $slideshow_url,
            'width' => $settings['width'],
            'height' => $settings['height'],
          ],
        ];
      }
    }

    return $element;
  }

  /**
   * {@inheritdoc}
   */
  public static function defaultSettings() {
    return [
      'width' => '480',
      'height' => '640',
    ] + parent::defaultSettings();
  }

  /**
   * {@inheritdoc}
   */
  public function settingsForm(array $form, FormStateInterface $form_state) {
    $elements = parent::settingsForm($form, $form_state);

    $elements['width'] = [
      '#type' => 'number',
      '#title' => t('Width'),
      '#default_value' => $this->getSetting('width'),
      '#min' => 1,
      '#description' => t('Width of SlideShare.'),
    ];

    $elements['height'] = [
      '#type' => 'number',
      '#title' => t('Height'),
      '#default_value' => $this->getSetting('height'),
      '#min' => 1,
      '#description' => t('Height of SlideShare.'),
    ];

    return $elements;
  }

  /**
   * Returns the value of a attribut.
   *
   * @param string $attribut_name
   *   The attribut name.
   *
   * @return string|null
   *   The attribut value.
   */
  public function getSetting($attribut_name) {
    return isset($this->{$attribut_name}) ? $this->{$attribut_name} : NULL;
  }

  /**
   * Get data via SlideShare API.
   *
   * @param string $login
   *   Login.
   * @param string $shortcode
   *   Short code.
   *
   * @return string
   *   The key.
   */
  public function getSlideshowUrl($login, $shortcode) {
    try {
      $ss = new ZendSlideShare($this->apiKey, $this->sharedSecret);
      $byurl = $ss->getSlideShowByUrl("http://www.slideshare.net/$login/$shortcode");

      return $byurl->getSlideshowEmbedUrl();
    }
    catch (RuntimeException $exception) {
      watchdog_exception(__CLASS__, $exception);
    }
    catch (HttpRuntimeException $exception) {
      watchdog_exception(__CLASS__, $exception);
    }
  }

}

==> media_entity_slideshare-8.x-1.3.tar.gz: media_entity_slideshare/src/Plugin/Field/FieldFormatter/SlideShareEmbedFormatter.php <==
<?php

namespace Drupal\media_entity_slideshare\Plugin\Field\FieldFormatter;

use Drupal\Core\Field\FieldItemListInterface;
use Drupal\Core\Field\FormatterBase;
use Drupal\Core\Form\FormStateInterface;
use Drupal\media_entity\EmbedCodeValueTrait;
use Drupal\media_entity_slideshare\Plugin\MediaEntity\Type\SlideShare;
use Drupal\Core\Plugin\ContainerFactoryPluginInterface;
use Drupal\Core\Field\FieldDefinitionInterface;
use Drupal\Core\Config\ConfigFactoryInterface;
use Symfony\Component\DependencyInjection\ContainerInterface;
use ZendService\SlideShare\SlideShare as ZendSlideShare;
use ZendService\SlideShare\Exception\RuntimeException;
use ZendService\SlideShare\HttpException\RuntimeException as HttpRuntimeException;

/**
 * Plugin implementation of the 'slideshare_embed' formatter.
 *
 * @FieldFormatter(
 *   id = "slideshare_embed",
 *   label = @Translation("SlideShare embed"),
 *   field_types = {
 *     "link", "string", "string_long"
 *   }
 * )
 */
class SlideShareEmbedFormatter extends FormatterBase implements ContainerFactoryPluginInterface {

  use EmbedCodeValueTrait;

  const URL = '//www.slideshare.net/slideshow/embed_code/key/';

  const API_URL = 'https://www.slideshare.net/api/2/get_slideshow';

  /**
   * API key.
   *
   * @var string $apiKey
   */
  protected $apiKey;

  /**
   * Shared secret.
   *
   * @var string $sharedSecret
   */
  protected $sharedSecret;

  /**
   * Constructs a new SlideShareEmbedFormatter.
   *
   * @param string $plugin_id
   *   The plugin_id for the formatter.
   * @param mixed $plugin_definition
   *   The plugin implementation definition.
   * @param \Drupal\Core\Field\FieldDefinitionInterface $field_definition
   *   The definition of the field to which the formatter is associated.
   * @param array $settings
   *   The formatter settings.
   * @param string $label
   *   The formatter label display setting.
   * @param string $view_mode
   *   The view mode.
   * @param array $third_party_settings
   *   Third party settings.
   * @param \Drupal\Core\Config\ConfigFactoryInterface $config_factory
   *   Config factory service.
   */
  public function __construct($plugin_id, $plugin_definition, FieldDefinitionInterface $field_definition, array $settings, $label, $view_mode, array $third_party_settings, ConfigFactoryInterface $config_factory) {
    parent::__construct($plugin_id, $plugin_definition, $field_definition, $settings, $label, $view_mode, $third_party_settings);

    $this->apiKey = $config_factory->get('media_entity_slideshare.settings')->get('api_key');
    $this->sharedSecret = $config_factory->get('media_entity_slideshare.settings')->get('shared_secret');
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container, array $configuration, $plugin_id, $plugin_definition) {
    return new static(
      $plugin_id,
      $plugin_definition,
      $configuration['field_definition'],
      $configuration['settings'],
      $configuration['label'],
      $configuration['view_mode'],
      $configuration['third_party_settings'],
      $container->get('config.factory')
    );
  }

  /**
   * {@inheritdoc}
   */
  public function viewElements(FieldItemListInterface $items, $langcode) {
    $element = [];
    $settings = $this->getSettings();

    /** @var \Drupal\Core\Field\FieldItemListInterface $item */
    foreach ($items as $delta => $item) {
      $slideshow_url = NULL;
      $matches = [];
      foreach (SlideShare::$validationRegexp as $pattern => $key) {
        if (preg_match($pattern, $this->getEmbedCode($item), $matches)) {
          break;
        }
      }

      if (!empty($matches['secretkey'])) {
        $slideshow_url = static::URL . $matches['secretkey'];
      }
      elseif (!empty($matches['shortcode'])) {
        $slideshow_url = $this->getSlideshowUrl($matches['login'], $matches['shortcode']);
      }

      if ($slideshow_url) {
        $element[$delta] = [
          '#type' => 'html_tag',
          '#tag' => 'iframe',
          '#attributes' => [
            'allowfullscreen' => 'true',
            'frameborder' => 0,
            'scrolling' => 'no',
            'src' => $slideshow_url,
            'width' => $settings['width'],
            'height' => $settings['height'],
          ],
        ];
      }
    }

    return $element;
  }

  /**
   * {@inheritdoc}
   */
  public static function defaultSettings() {
    return [
      'width' => '480',
      'height' => '640',
    ] + parent::defaultSettings();
  }

  /**
   * {@inheritdoc}
   */
  public function settingsForm(array $form, FormStateInterface $form_state) {
    $elements = parent::settingsForm($form, $form_state);

    $elements['width'] = [
      '#type' => 'number',
      '#title' => $this->t('Width'),
      '#default_value' => $this->getSetting('width'),
      '#min' => 1,
      '#description' => $this->t('Width of SlideShare.'),
    ];

    $elements['height'] = [
      '#type' => 'number',
      '#title' => $this->t('Height'),
      '#default_value' => $this->getSetting('height'),
      '#min' => 1,
      '#description' => $this->t('Height of SlideShare.'),
    ];

    return $elements;
  }

  /**
   * {@inheritdoc}
   */
  public function settingsSummary() {
    return [
      $this->t('Width: @width px', [
        '@width' => $this->getSetting('width'),
      ]),
      $this->t('Height: @height px', [
        '@height' => $this->getSetting('height'),
      ]),
    ];
  }

  /**
   * Get data via SlideShare API.
   *
   * @param string $login
   *   Login.
   * @param string $shortcode
   *   Short code.
   *
   * @return string
   *   The key.
   */
  public function getSlideshowUrl($login, $shortcode) {
    try {
      /** @var \ZendService\SlideShare\SlideShare $ss */
      $ss = new ZendSlideShare($this->apiKey, $this->sharedSecret);
      /** @var \ZendService\SlideShare\SlideShow $byurl */
      $byurl = $ss->getSlideShowByUrl("http://www.slideshare.net/$login/$shortcode");

      return $byurl->getSlideshowEmbedUrl();
    }
    catch (RuntimeException $exception) {
      watchdog_exception(__CLASS__, $exception);
    }
    catch (HttpRuntimeException $exception) {
      watchdog_exception(__CLASS__, $exception);
    }
  }

}
